@@ -3,7 +3,7 @@ package Socket;
 use strict;
 { use 5.006001; }
 
-our $VERSION = '1.99';
+our $VERSION = '2.001_001';
 
 =head1 NAME
 
@@ -241,6 +241,18 @@ pack_sockaddr_un() or unpack_sockaddr_un() explicitly.
 
 These are only supported if your system has E<lt>F<sys/un.h>E<gt>.
 
+=head2 $ip_mreq = pack_ip_mreq $multiaddr, $interface
+
+Takes an IPv4 multicast address and optionally an interface address (or
+C<INADDR_ANY>). Returns the C<ip_mreq> structure with those arguments packed
+in. Suitable for use with the C<IP_ADD_MEMBERSHIP> and C<IP_DROP_MEMBERSHIP>
+sockopts.
+
+=head2 ($multiaddr, $interface) = unpack_ip_mreq $ip_mreq
+
+Takes an C<ip_mreq> structure. Returns a list of two elements; the IPv4
+multicast address and interface address.
+
 =head2 $ipv6_mreq = pack_ipv6_mreq $ip6_address, $ifindex
 
 Takes an IPv6 address and an interface number. Returns the C<ipv6_mreq>
@@ -286,7 +298,7 @@ code should use getnameinfo() or inet_ntop() instead for IPv6 support.
 =head2 $address = inet_pton $family, $string
 
 Takes an address family (such as C<AF_INET> or C<AF_INET6>) and a string
-giving the name of a host, or a textual representation of an IP address and
+containing a textual representation of an address in that family and
 translates that to an packed binary address structure.
 
 See also getaddrinfo() for a more powerful and flexible function to look up
@@ -715,6 +727,9 @@ our @EXPORT = qw(
 our @EXPORT_OK = qw(
 	CR LF CRLF $CR $LF $CRLF
 
+	IP_ADD_MEMBERSHIP IP_DROP_MEMBERSHIP IP_MULTICAST_IF
+	IP_MULTICAST_LOOP IP_MULTICAST_TTL
+
 	IPPROTO_IP IPPROTO_IPV6 IPPROTO_RAW IPPROTO_ICMP IPPROTO_TCP
 	IPPROTO_UDP
 
@@ -729,6 +744,8 @@ our @EXPORT_OK = qw(
 	IPV6_MULTICAST_HOPS IPV6_MULTICAST_IF IPV6_MULTICAST_LOOP
 	IPV6_UNICAST_HOPS IPV6_V6ONLY
 
+	pack_ip_mreq unpack_ip_mreq
+
 	pack_ipv6_mreq unpack_ipv6_mreq
 
 	inet_pton inet_ntop
